#!/usr/bin/env python
import matplotlib.pyplot as plt
import numpy as np
from libhreels import calcHREELS20
import os

###### Define Strontium titanate film on Silver ####
## (Thickness is given in Angstroem as second parm)#
thinFilm = [[{
        "eps": 5.25,
        "wTO": [393.7],
        "gTO": [10.8],
        "wLO": [584.7],
        "gLO": [10.8],
        "reference": "Schumann'22",
        "name": "NiO"
    }, 300000.]]
d = calcHREELS20.lambin(thinFilm)
x = np.linspace(-100,1000,1100)
x,y = d.calcHREELS(x)

###### Plotting ###########################
plt.plot(x,y, label='NiO(001)')

plt.ylabel('Relative HREELS signal')
plt.xlabel('Energy Loss (cm$^{-1}$)')
plt.title(r"F.O.Schumann'22")
plt.ylim(bottom=0.)
plt.legend()

plt.text(0.99, 0.01,os.path.basename(__file__), fontsize=10, ha='right', va='bottom', transform=plt.gcf().transFigure)
output_filename = os.path.splitext(__file__)[0] + '.png'
plt.savefig(output_filename)

plt.show()